'''
    定时任务仓库 存放一些定时任务的类和方法
'''
__all__ = [
    'task_video_auto', 'task_comment_auto', 'task_selenium_auto', 'task_contentImgs_auto', 'task_thumbnailImgs_auto',
    'task_keyParagraph_auto', 'task_relativeParagraph_auto'
]
# 主要任务
'''
    1 段落内容的处理及上传
    2 图片内容的下载处理及上传
    3 评论内容的处理及上传
    4 视频内容的下载处理及上传
    （处理包括筛选过滤和清除）
    
    配置文件：
        
'''
